vfbLib.parsers.glyph.GlyphSketchParser
======================================

.. currentmodule:: vfbLib.parsers.glyph

.. autoclass:: GlyphSketchParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphSketchParser.__init__
      ~GlyphSketchParser.parse
      ~GlyphSketchParser.parse_hex
      ~GlyphSketchParser.read_double
      ~GlyphSketchParser.read_doubles
      ~GlyphSketchParser.read_float
      ~GlyphSketchParser.read_floats
      ~GlyphSketchParser.read_int16
      ~GlyphSketchParser.read_int32
      ~GlyphSketchParser.read_int8
      ~GlyphSketchParser.read_str
      ~GlyphSketchParser.read_str_all
      ~GlyphSketchParser.read_uint16
      ~GlyphSketchParser.read_uint32
      ~GlyphSketchParser.read_uint8
      ~GlyphSketchParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphSketchParser.encoding
      ~GlyphSketchParser.master_count
      ~GlyphSketchParser.stream
      ~GlyphSketchParser.ttStemsH_count
      ~GlyphSketchParser.ttStemsV_count
   
   